OpcodeInfo

Struct OpcodeInfo 

pub struct OpcodeInfo(u32);
Opcode information.

Tuple Fields

0: u32

Implementations



impl OpcodeInfo

pub const UNKNOWN: u32

The unknown flag.

pub const DYNAMIC: u32

The dynamic flag.

pub const DISABLED: u32

The disabled flag.

pub const MASK: u32 = 0xFFFF

The mask for the gas cost (16 bits, max 65535).

pub const fn new(gas: u16) -> OpcodeInfo

Creates a new gas info with the given gas cost.

pub const fn is_unknown(self) -> bool

Returns true if the opcode is unknown.

pub const fn is_dynamic(self) -> bool

Returns true if the gas cost is dynamic.

pub const fn is_disabled(self) -> bool

Returns true if the opcode is known, but disabled in the current EVM version.

pub const fn base_gas(self) -> u16

Returns the base gas cost of the opcode.

This may not be the final/full gas cost of the opcode as it may also have a dynamic cost.

pub fn set_unknown(&mut self)

Sets the unknown flag.

pub fn set_dynamic(&mut self)

Sets the dynamic flag.

pub fn set_disabled(&mut self)

Sets the disabled flag.

pub fn set_gas(&mut self, gas: u16)

Sets the gas cost.